> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #DAC 3 Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example
```
#include "dac_3_hw.h"
#include "resources.h"

//TFT pins
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8;
sbit TFT_RS at GPIOE_ODR.B12;
sbit TFT_CS at GPIOE_ODR.B15;
sbit TFT_RD at GPIOE_ODR.B10;
sbit TFT_WR at GPIOE_ODR.B11;
sbit TFT_BLED at GPIOE_ODR.B9;

// Variables
volatile int current;

void system_init()
{
    I2C1_Init_Advanced( 400000, &_GPIO_MODULE_I2C1_PB67 );
    Delay_ms ( 500 );
    
    GPIO_Digital_Input( &GPIOC_BASE, _GPIO_PINMASK_7 );
    GPIO_Digital_Input( &GPIOC_BASE, _GPIO_PINMASK_3 );
    
    current = 2048;
}

void display_init()
{
    TFT_Init_ILI9341_8bit( 320, 240 );
    TFT_BLED = 1;
    TFT_Set_Pen( CL_WHITE, 1 );
    TFT_Set_Brush( 1,CL_WHITE,0,0,0,0 );
    TFT_Set_Font( TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );
    TFT_Fill_Screen( CL_WHITE );
    TFT_Set_Pen( CL_BLACK, 1 );
    TFT_Line(  20,  46, 300,  46 );
    TFT_Line(  20,  70, 300,  70 );
    TFT_Line(  20, 196, 300, 196 );;
    TFT_Line(  20, 220, 300, 220 );
    TFT_Set_Pen( CL_WHITE, 1 );
    TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( "DAC  3  click", 95, 14 );
    TFT_Set_Font( &Tahoma15x16_Bold, CL_BLUE, FO_HORIZONTAL );
    TFT_Write_Text( "MCP 4726", 118, 50 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL );
    TFT_Write_Text("EasyMx PRO v7 for STM32", 19, 223);
    TFT_Set_Font( &Verdana12x13_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( "www.mikroe.com", 200, 223 );
    TFT_Set_Font( &Tahoma15x16_Bold, CL_BLUE, FO_HORIZONTAL );
    TFT_Write_Text( "Reference voltage 3.3 V", 80, 200 );
    TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_BLACK, FO_HORIZONTAL );
    TFT_Write_Text( "Current output ratio", 60, 90 );
}

void display_percentage()
{
    char tmp_txt[10];
    
    sprintf( tmp_txt, "%.3f", ( float )current / 4095 );
    TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( tmp_txt , 125, 140 );
    dac_3_write_all_mem( VREF_BUFFERED, NORMAL, GAIN_1x, current );
}

void inc_voltage()
{
    char tmp_txt[10];
    
    if ( current < 4091 )
    {
        current += 4;
        sprintf( tmp_txt, "%.3f", ( float )current / 4095 );
        TFT_Rectangle( 120, 135, 195, 165 );
        TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL );
        TFT_Write_Text( tmp_txt , 125, 140 );
        dac_3_write_all_mem( VREF_BUFFERED, NORMAL, GAIN_1x, current );
    }
}

void dec_voltage()
{
    char tmp_txt[10];

    if ( current > 4 )
    {
        current += -4;
        sprintf( tmp_txt, "%.3f", ( float )current / 4095 );
        TFT_Rectangle( 120, 135, 195, 165 );
        TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL );
        TFT_Write_Text( tmp_txt , 125, 140 );
        dac_3_write_all_mem( VREF_BUFFERED, NORMAL, GAIN_1x, current );
    }
}

void main() 
{
    system_init();
    display_init();
    dac_3_init( 0x60 );
    Delay_ms( 100 );

    dac_3_reset();
    dac_3_wake_up();
    display_percentage();

    while( 1 )
    {
        if ( Button( &GPIOC_IDR, 7, 20, 1 ) )
             dec_voltage();

        if ( Button( &GPIOC_IDR, 3, 20, 1 ) )
             inc_voltage();
    }
}
```
